@@ -4,6 +4,7 @@ import sys
 import unittest
 from contextlib import contextmanager
 
+from slugify import PRE_TRANSLATIONS
 from slugify import slugify
 from slugify import smart_truncate
 from slugify.__main__ import slugify_params, parse_args
@@ -36,6 +37,10 @@ class TestSlugify(unittest.TestCase):
         self.assertEqual(r, "ying-shi-ma")
 
     def test_accented_text(self):
+        txt = '𝐚́́𝕒́àáâäãąā'
+        r = slugify(txt)
+        self.assertEqual(r, "aaaaaaaaa")
+
         txt = 'C\'est déjà l\'été.'
         r = slugify(txt)
         self.assertEqual(r, "c-est-deja-l-ete")
@@ -232,9 +237,11 @@ class TestSlugify(unittest.TestCase):
         r = slugify(txt, replacements=[['Ü', 'UE'], ['ü', 'ue']])
         self.assertEqual(r, "ueber-ueber-german-umlaut")
 
+    def test_pre_translation(self):
+        self.assertEqual(PRE_TRANSLATIONS, [('Ю', 'U'), ('Щ', 'Sch'), ('У', 'Y'), ('Х', 'H'), ('Я', 'Ya'), ('Ё', 'E'), ('ё', 'e'), ('я', 'ya'), ('х', 'h'), ('у', 'y'), ('щ', 'sch'), ('ю', 'u'), ('Ü', 'Ue'), ('Ö', 'Oe'), ('Ä', 'Ae'), ('ä', 'ae'), ('ö', 'oe'), ('ü', 'ue'), ('Ϋ́', 'Y'), ('Ϋ', 'Y'), ('Ύ', 'Y'), ('Υ', 'Y'), ('Χ', 'Ch'), ('χ', 'ch'), ('Ξ', 'X'), ('ϒ', 'Y'), ('υ', 'y'), ('ύ', 'y'), ('ϋ', 'y'), ('ΰ', 'y')])
+
 
 class TestSlugifyUnicode(unittest.TestCase):
-
     def test_extraneous_seperators(self):
 
         txt = "This is a test ---"
